Fcmp CLI library modules.
Modules
Command line interface options.
Structs
An error indicating a failure to parse a MissingFileBehavior.
Enums
A diff operation.
Options for handling missing files.
Functions
Takes an iterator of Paths and returns the index of the most recently
modified file.
Returns the ordering of two files based on their modification times. The order is a partial order, and as such, None will be returned if the file modification times cannot be determined.